# Langchain YouTube Search Agent

This agent utilizes the Langchain YoutubeSearchTool to search Youtube Videos.
You need to install the following dependencies:

```python
uv pip install youtube_search
``` 
